@@ -436,6 +436,10 @@ window_cb_key_press(GtkWidget* widget, GdkEventKey *event)
             _speed_limit_on ^= 1;
             break;
 
+        case CUSTOM_ACTION_TOGGLE_LAYERS:
+            maps_toggle_visible_layers ();
+            break;
+
         default:
             vprintf("%s(): return FALSE\n", __PRETTY_FUNCTION__);
             return FALSE;
@@ -452,7 +456,7 @@ window_cb_key_release(GtkWidget* widget, GdkEventKey *event)
     printf("%s()\n", __PRETTY_FUNCTION__);
 
     custom_key = get_custom_key_from_keyval(event->keyval);
-    if(custom_key < 0)
+    if(custom_key == -1)
         return FALSE; /* Not our event. */
 
     switch(_action[custom_key])
@@ -639,7 +643,22 @@ map_cb_button_release(GtkWidget *widget, GdkEventButton *event)
         Point clkpt;
         screen2unit(event->x, event->y, clkpt.unitx, clkpt.unity);
 
+#ifdef INCLUDE_APRS        
+        gboolean aprs_found = FALSE;
+
+        if(_aprs_enable &&  (_poi_zoom > _zoom) )
+        {
+            AprsDisplayData poi;
+            selected_point = select_aprs(
+                    clkpt.unitx, clkpt.unity, TRUE);
+            
+            aprs_found = selected_point;
+        }
+
+        if(!aprs_found && _show_poi && (_poi_zoom > _zoom))
+#else
         if(_show_poi && (_poi_zoom > _zoom))
+#endif // INCLUDE_APRS
         {
             PoiInfo poi;
             selected_point = select_poi(
